@@ -12,10 +12,11 @@ write new modules on the platform::
 """
 import os
 
-VERSION = '3.6.2'
+VERSION = "3.7.1"
+
 
 def _get_git_revision(path):
-    revision_file = os.path.join(path, 'refs', 'heads', 'master')
+    revision_file = os.path.join(path, "refs", "heads", "master")
     if os.path.exists(revision_file):
         with open(revision_file) as fh:
             return fh.read().strip()[:7]
@@ -28,7 +29,7 @@ def get_revision():
     """
     package_dir = os.path.dirname(__file__)
     checkout_dir = os.path.normpath(os.path.join(package_dir, os.pardir))
-    path = os.path.join(checkout_dir, '.git')
+    path = os.path.join(checkout_dir, ".git")
     if os.path.exists(path):
         return _get_git_revision(path)
 
@@ -36,19 +37,19 @@ def get_revision():
 def get_version():
     base = VERSION
     if __build__:
-        base = '%s (%s)' % (base, __build__)
+        base = "%s (%s)" % (base, __build__)
     return base
 
 
 __build__ = get_revision()
-__version__ = VERSION 
+__version__ = VERSION
 
-from .core import * 
-from .package import * 
-from .lib import * 
-from .commands import * 
+from .core import *
+from .package import *
+from .lib import *
+from .commands import *
 from .tasks import *
-from .services import * 
-from .datasets import * 
+from .services import *
+from .datasets import *
 from .quality import *
 from . import featurestore, realtime, contrib, utils, notebook, feature_compute
